@@ -46,6 +46,21 @@ and "dark". "info", "success", "warning", and "danger" are also allowed.
     primary: "#763722"
     secondary: "#E4A042"
 
+A good colour generator can be found at L<https://huemint.com/bootstrap-basic/>
+if you're stuck for ideas.
+
+The C<theme> hashref can also include Bootstrap's non-colour SASS options.
+See L<https://getbootstrap.com/docs/5.2/customize/options/>.
+
+An example is:
+
+  theme:
+    light: "#e4e3e1"
+    dark: "#32201D"
+    primary: "#763722"
+    secondary: "#E4A042"
+    "enable-shadows": "true"
+
 =item C<< name >> I<< (required) >>
 
 The name of the project you're building a website for. This is assumed
@@ -246,7 +261,7 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 use Moo;
 use Web::PerlDistSite::Common -lexical, -all;
 
-our $VERSION = '0.001008';
+our $VERSION = '0.001009';
 
 use Web::PerlDistSite::MenuItem ();
 use HTML::HTML5::Parser ();
@@ -504,7 +519,7 @@ __DATA__
 	<body id="top">
 		<header></header>
 		<main></main>
-		<div style="height: 150px; overflow: hidden;"><svg viewBox="0 0 500 150" preserveAspectRatio="none" style="height: 100%; width: 100%;"><path d="M0.00,49.98 C138.82,121.67 349.20,-49.98 500.00,49.98 L500.00,150.00 L0.00,150.00 Z" style="stroke: none; fill: rgba(var(--bs-dark-rgb), 1);"></path></svg></div>
+		<div id="footer-swish" style="height: 150px; overflow: hidden;"><svg viewBox="0 0 500 150" preserveAspectRatio="none" style="height: 100%; width: 100%;"><path d="M0.00,49.98 C138.82,121.67 349.20,-49.98 500.00,49.98 L500.00,150.00 L0.00,150.00 Z" style="stroke: none; fill: rgba(var(--bs-dark-rgb), 1);"></path></svg></div>
 		<footer id="bottom"></footer>
 		<a id="return-to-top" href="#top"><i class="fa-solid fa-circle-up"></i></a>
 		<script src="{{ $root }}assets/scripts/bootstrap.bundle.min.js"></script>
